"""QueryBuilder tests."""
import pytest


@pytest.mark.usefixtures("table_creator")
class TestQueryBuilder(object):
    """QueryBuilder tests."""

    pass
